.. Please when editing this file make sure to keep it matching the
   docs in ../configuration.rst:reference_to_examples

sphinx_gallery.downloads
========================

.. automodule:: sphinx_gallery.downloads

   
   

   Functions
   ---------

   

   .. autofunction:: generate_zipfiles

   .. include:: backreferences/sphinx_gallery.downloads.generate_zipfiles.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: list_downloadable_sources

   .. include:: backreferences/sphinx_gallery.downloads.list_downloadable_sources.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: python_zip

   .. include:: backreferences/sphinx_gallery.downloads.python_zip.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>
   
   

   
   
   

   
   
   